aboutsummaryrefslogtreecommitdiffstats
path: root/OpenAL32/Include/alMain.h
diff options
context:
space:
mode:
Diffstat (limited to 'OpenAL32/Include/alMain.h')
-rw-r--r--OpenAL32/Include/alMain.h5
1 files changed, 2 insertions, 3 deletions
diff --git a/OpenAL32/Include/alMain.h b/OpenAL32/Include/alMain.h
index a0251042..9b1bcca9 100644
--- a/OpenAL32/Include/alMain.h
+++ b/OpenAL32/Include/alMain.h
@@ -358,9 +358,8 @@ struct ALCdevice_struct
// Map of Buffers for this device
UIntMap BufferMap;
- // Linked List of Effects for this device
- struct ALeffect *EffectList;
- ALuint EffectCount;
+ // Map of Effects for this device
+ UIntMap EffectMap;
// Linked List of Filters for this device
struct ALfilter *FilterList;